Method: Azure::ServiceBus::Subscription#enable_batched_operations

Defined in:
lib/azure/service_bus/subscription.rb

#enable_batched_operationsObject

EnableBatchedOperations

Enables or disables service side batching behavior when performing operations for the specific queue. When enabled, service bus will collect/batch multiple operations to the backend to be more connection efficient. If user wants lower operation latency then they can disable this feature.



140
141
142
# File 'lib/azure/service_bus/subscription.rb', line 140

def enable_batched_operations
  to_bool description['EnableBatchedOperations']
end